@@ -2,7 +2,7 @@
  * (c)LGPL2+
  *
  * LXQt - a lightweight, Qt based, desktop toolset
- * http://lxqt.org
+ * https://lxqt.org
  *
  * Copyright: 2014 LXQt team
  * Authors:
@@ -33,6 +33,8 @@
 #include <QMap>
 #include <QDebug>
 
+#include <LXQt/Settings>
+
 #include "datetime.h"
 #include "timezone.h"
 
@@ -46,7 +48,7 @@ TimeAdminDialog::TimeAdminDialog(QWidget *parent):
 
     mDateTimeWidget = new DateTimePage(mTimeDateCtl.useNtp(), mTimeDateCtl.localRtc(), this);
     addPage(mDateTimeWidget,tr("Date and time"));
-    connect(this,SIGNAL(reset()),mDateTimeWidget,SLOT(reload()));
+    connect(this, &LXQt::ConfigDialog::reset, mDateTimeWidget,&DateTimePage::reload);
     connect(mDateTimeWidget,&DateTimePage::changed,this,&TimeAdminDialog::onChanged);
 
     QStringList zones;
