@@ -34,11 +34,14 @@ MainWindow::MainWindow():
     mUserManager(new UserManager(this))
 {
     ui.setupUi(this);
-    connect(ui.actionAdd, SIGNAL(triggered(bool)), SLOT(onAdd()));
-    connect(ui.actionDelete, SIGNAL(triggered(bool)), SLOT(onDelete()));
-    connect(ui.actionProperties, SIGNAL(triggered(bool)), SLOT(onEditProperties()));
-    connect(ui.actionChangePasswd, SIGNAL(triggered(bool)), SLOT(onChangePasswd()));
-    connect(ui.actionRefresh, SIGNAL(triggered(bool)), SLOT(reload()));
+    ui.userList->sortByColumn(0, Qt::AscendingOrder);
+    ui.groupList->sortByColumn(0, Qt::AscendingOrder);
+
+    connect(ui.actionAdd, &QAction::triggered, this, &MainWindow::onAdd);
+    connect(ui.actionDelete, &QAction::triggered, this, &MainWindow::onDelete);
+    connect(ui.actionProperties, &QAction::triggered, this, &MainWindow::onEditProperties);
+    connect(ui.actionChangePasswd, &QAction::triggered, this, &MainWindow::onChangePasswd);
+    connect(ui.actionRefresh, &QAction::triggered, this, &MainWindow::reload);
 
 #ifdef Q_OS_FREEBSD //Disable group gpasswd for FreeBSD
     connect(ui.tabWidget, &QTabWidget::currentChanged, [this](int index) {
@@ -51,6 +54,7 @@ MainWindow::MainWindow():
 #endif
     connect(ui.userList, &QListWidget::activated, this, &MainWindow::onRowActivated);
     connect(ui.groupList, &QListWidget::activated, this, &MainWindow::onRowActivated);
+    connect(ui.showSystemUsers, &QCheckBox::stateChanged, this, &MainWindow::reload);
 
     connect(mUserManager, &UserManager::changed, this, &MainWindow::reload);
     reload();
@@ -62,12 +66,13 @@ MainWindow::~MainWindow()
 
 void MainWindow::reloadUsers()
 {
-    ui.userList->clear();
+    QList<QTreeWidgetItem *> items;
     const auto& users = mUserManager->users();
+    items.reserve(users.size());
     for(const UserInfo* user: users)
     {
         uid_t uid = user->uid();
-        if(uid > 499 && !user->shell().isEmpty()) // exclude system users
+        if(ui.showSystemUsers->isChecked() || (uid > 499 && !user->shell().isEmpty())) // exclude system users
         {
             QTreeWidgetItem* item = new QTreeWidgetItem();
             item->setData(0, Qt::DisplayRole, user->name());
@@ -80,16 +85,19 @@ void MainWindow::reloadUsers()
                 item->setData(3, Qt::DisplayRole, group->name());
             }
             item->setData(4, Qt::DisplayRole, user->homeDir());
-            ui.userList->addTopLevelItem(item);
+            items.append(item);
         }
     }
+    ui.userList->clear();
+    ui.userList->addTopLevelItems(items);
 }
 
 void MainWindow::reloadGroups()
 {
-    ui.groupList->clear();
     // load groups
+    QList<QTreeWidgetItem *> items;
     const auto& groups = mUserManager->groups();
+    items.reserve(groups.size());
     for(const GroupInfo* group: groups)
     {
         QTreeWidgetItem* item = new QTreeWidgetItem();
@@ -98,8 +106,10 @@ void MainWindow::reloadGroups()
         item->setData(0, Qt::UserRole, obj);
         item->setData(1, Qt::DisplayRole, group->gid());
         item->setData(2, Qt::DisplayRole, group->members().join(", "));
-        ui.groupList->addTopLevelItem(item);
+        items.append(item);
     }
+    ui.groupList->clear();
+    ui.groupList->addTopLevelItems(items);
 }
 
 void MainWindow::reload() {
